# Maintainers

See [Governance](governance.md) for what each maintainer type is

## Project maintainers

In alphabetical order

| Name           | GitHub Username  | Email                       | Organization       |
| -------------- | ---------------- | --------------------------- | ------------------ |
| Abhin Chhabra  | `chhabrakadabra` | chhabra.abhin@gmail.com     | Shopify            |
| Achal Shah     | `achals`         | achals@gmail.com            | Tecton             |
| Danny Chiao    | `adchia`         | d.chiao@gmail.com           | Tecton             |
| David Liu      | `mavysavydav`    | davidyliuliu@gmail.com      | Twitter            |
| Felix Wang     | `felixwang9817`  | wangfelix98@gmail.com       | Tecton             |
| Kevin Zhang    | `kevjumba`       | kevin.zhang.13499@gmail.com | Tecton             |
| Matt Delacour  | `MattDelac`      | mdelacour@hey.com           | (formerly) Shopify |
| Miles Adkins   | `sfc-gh-madkins` | miles.adkins@snowflake.com  | Snowflake          |
| Willem Pienaar | `woop`           | will.pienaar@gmail.com      | Tecton             |
| Zhiling Chen   | `zhilingc`       | chnzhlng@gmail.com          | GetGround          |

## Area maintainers

Generally, with contribution questions here, default to `#feast-development` in the [slack.feast.dev](slack.feast.dev) Slack channel, but these may be folks for you to tag in messages

| Area                 | Description                                                                | Name                                          |
| -------------------- | -------------------------------------------------------------------------- | --------------------------------------------- |
| Data ingestion       | ingesting batch + stream data into the online store (materialization)      | Achal Shah,  <br>Felix Wang,  <br>Kevin Zhang |
| Developer experience | tooling, testing, documentation, tutorials                                 | Achal Shah                                    |
| Feature serving      | optimization, caching, deployment patterns, batch retrieval, range queries | Dvir Dukhan                                   |
| Ops                  | general deployment concerns, CI/CD, versioning                             | Keith Adler,  <br>Danny Chiao, <br>Felix Wang |
| Web UI               | i.e. `feast ui` output                                                     | Danny Chiao,  <br>David Liu                   |

## Emeritus Maintainers

| Name                | GitHub Username | Email                       | Organization |
| ------------------- | --------------- | --------------------------- | ------------ |
| Oleg Avdeev         | oavdeev         | oleg.v.avdeev@gmail.com     | Tecton       |
| Oleksii Moskalenko  | pyalex          | moskalenko.alexey@gmail.com | Tecton       |
| Jay Parthasarthy    | jparthasarthy   | jparthasarthy@gmail.com     | Tecton       |
| Pradithya Aria Pura | pradithya       | pradithya.aria@gmail.com    | Gojek        |
| Tsotne Tabidze      | tsotnet         | tsotnet@gmail.com           | Tecton       |